@@ -1,9 +1,16 @@
+"""
+Logger
+"""
+
 import logging
 from flask import has_request_context, request
 from flask.logging import default_handler
 
 
 class RequestFormatter(logging.Formatter):
+    """
+    Request formatter to handle log format
+    """
     def format(self, record):
         if has_request_context():
             record.url = request.url
